.. _changelog:

.. include:: ../../CHANGES.rst
   :start-after: begin_changelog_intro
   :end-before: end_changelog_intro

.. include:: ../../CHANGES.rst
   :start-after: begin_changelog_body
   :end-before: end_changelog_body
